@@ -10,6 +10,7 @@ import re
 from .abc import Criteria
 from .sequence import StrSequence, EnSequence
 from .symbols import SYMBOLS, SYMBOLS_EN
+from .white_list import data
 
 
 class IsEndState(Criteria):
@@ -20,43 +21,75 @@ class IsEndState(Criteria):
         return state.reach_right_end()
 
 
-class IsEndSymbolCN(Criteria):
-    def __init__(self, symbols: dict):
-        super(IsEndSymbolCN, self).__init__('IsEndSymbolZH', symbols)
-        self.empty = re.compile('\s')
+class IsEndSymbolZH(Criteria):
+    def __init__(self, symbols: dict, white_list: str = data):
+        super(IsEndSymbolZH, self).__init__('IsEndSymbolEN', symbols)
+        self.empty = re.compile('^\s+$')
+        self.number = re.compile('[0-9]')
+        self.is_right_quota = IsRightQuotaEn()
+        self.is_right_s_quota = IsRightSingleQuotaEn()
 
-    def is_zh(self, char: str):
-        if '\u4e00' <= char <= '\u9fa5':
-            return True
+    def look_forward(self, state: StrSequence) -> str:
+        for i in range(state.v_pointer + 1, state.length):
+            if not self.empty.match(state[i]):
+                return state[i]
+        else:
+            return state.current_value
+
+    def look_backward(self, state: StrSequence) -> str:
+        for i in range(0, state.v_pointer)[::-1]:
+            if not self.empty.match(state[i]):
+                return state[i]
+        else:
+            return state.current_value
 
     def accept(self, state: StrSequence) -> bool:
-        if self.symbols['end_symbols'].match(state.current_value) and \
-                not (self.symbols['en_dot'].match(state.next_value) or self.symbols['end_symbols'].match(
-                    state.next_value)):
+        if self.symbols['end_symbols'].match(state.current_value) and not self.symbols['all_symbols'].match(
+                self.look_forward(state)):
+            return True
+        if (self.is_right_quota(state) or self.is_right_s_quota(state)) and self.symbols['end_symbols'].match(
+                self.look_backward(state)):
             return True
         if self.symbols['en_dot'].match(state.current_value):
-            if self.is_zh(state.next_value) or self.empty.match(state.next_value):
+            if self.number.match(state.next_value):
+                return False
+            else:
                 return True
         return False
 
 
 class IsEndSymbolEN(Criteria):
-    def __init__(self, symbols: dict):
+    def __init__(self, symbols: dict, white_list: str = data):
         super(IsEndSymbolEN, self).__init__('IsEndSymbolEN', symbols)
-        self.empty = re.compile('\s')
+        self.empty = re.compile('^\s+$')
         self.number = re.compile('[0-9]')
+        self.is_right_quota = IsRightQuotaEn()
+        self.is_right_s_quota = IsRightSingleQuotaEn()
+        self.not_in_white_list = NotInWhitelistDotEn(white_list=white_list)
+
+    def look_forward(self, state: StrSequence) -> str:
+        for i in range(state.v_pointer + 1, state.length):
+            if not self.empty.match(state[i]):
+                return state[i]
+        else:
+            return state.current_value
+
+    def look_backward(self, state: StrSequence) -> str:
+        for i in range(0, state.v_pointer)[::-1]:
+            if not self.empty.match(state[i]):
+                return state[i]
+        else:
+            return state.current_value
 
     def accept(self, state: StrSequence) -> bool:
-        if self.symbols['end_symbols'].match(state.current_value) and \
-                not (self.symbols['en_dot'].match(state.next_value) or self.symbols['end_symbols'].match(
-                    state.next_value)):
+        if self.symbols['end_symbols'].match(state.current_value):
+            print()
+        if self.symbols['end_symbols'].match(state.current_value) and not self.symbols['end_symbols'].match(
+                self.look_forward(state)):
+            return True
+        if (self.is_right_quota(state) or self.is_right_s_quota(state)) and self.symbols['end_symbols'].match(
+                self.look_backward(state)) and self.look_forward(state)[0].isupper():
             return True
-        if self.symbols['en_dot'].match(state.current_value):
-
-            if self.number.match(state.next_value):
-                return False
-            else:
-                return True
         return False
 
 
@@ -469,7 +502,34 @@ class NotInWhitelistDotEn(SpecialCondition):
         self.white_list = [pattern.sub('', v.strip()) for v in white_list.splitlines()]
 
     def accept(self, state: EnSequence) -> bool:
-        if not state.current_value in ['.', '!']:
+        return self.is_valid(state, state.v_pointer)
+        # if not state.current_value in ['.', '!']:
+        #     return True
+        # else:
+        #     for word in self.white_list:
+        #         if not word:
+        #             continue
+        #         word_token = state.tokenize(word)
+        #         dots_pos = self.find_dot(word_token)
+        #         word_len = len(word_token)
+        #         atcual_word = ''.join(state[state.v_pointer - dots_pos:state.v_pointer])
+        #         if dots_pos == word_len and word == atcual_word:
+        #             return False
+        #         if dots_pos != word_len:
+        #             # case Mac. book 走搜索
+        #             while dots_pos > 0:
+        #                 i = 0
+        #                 whole_word = atcual_word + ''.join(
+        #                     state[state.v_pointer:state.v_pointer + i + word_len - dots_pos])
+        #                 if word == whole_word:
+        #                     # state.v_pointer = state.v_pointer + i + word_len - dots_pos
+        #                     return False
+        #                 dots_pos = self.find_dot(word_token, dots_pos + 1)
+        #                 atcual_word = ''.join(state[state.v_pointer - dots_pos:state.v_pointer])
+        #     return True
+
+    def is_valid(self, state: EnSequence, index: int):
+        if not state[index] in ['.', '!']:
             return True
         else:
             for word in self.white_list:
@@ -478,7 +538,7 @@ class NotInWhitelistDotEn(SpecialCondition):
                 word_token = state.tokenize(word)
                 dots_pos = self.find_dot(word_token)
                 word_len = len(word_token)
-                atcual_word = ''.join(state[state.v_pointer - dots_pos:state.v_pointer])
+                atcual_word = ''.join(state[index - dots_pos:index])
                 if dots_pos == word_len and word == atcual_word:
                     return False
                 if dots_pos != word_len:
@@ -486,12 +546,12 @@ class NotInWhitelistDotEn(SpecialCondition):
                     while dots_pos > 0:
                         i = 0
                         whole_word = atcual_word + ''.join(
-                            state[state.v_pointer:state.v_pointer + i + word_len - dots_pos])
+                            state[index:index + i + word_len - dots_pos])
                         if word == whole_word:
-                            state.v_pointer = state.v_pointer + i + word_len - dots_pos
+                            # state.v_pointer = state.v_pointer + i + word_len - dots_pos
                             return False
                         dots_pos = self.find_dot(word_token, dots_pos + 1)
-                        atcual_word = ''.join(state[state.v_pointer - dots_pos:state.v_pointer])
+                        atcual_word = ''.join(state[index - dots_pos:index])
             return True
 
     def find_dot(self, str_list: List[str], start=0):
