@@ -157,7 +157,8 @@ class EnSequence(StrSequence):
             elif self.v_pointer == self.length - 1:
                 return True
             elif self.is_blank.match(self.pre_value) or self.is_blank.match(self.next_value):
-                return True
+                if self.pre_value not in ['s','n']:
+                    return True
             else:
                 return False
         return False
