@@ -14,7 +14,7 @@ SYMBOLS = {
     'book_left': re.compile('([《])'),
     'book_right': re.compile('([》])'),
     'comma': re.compile('([,，;])'),
-    'end_symbols': re.compile('([?\!…;？！。])'),
+    'end_symbols': re.compile('([?\!…;？！。\.])'),
     'en_dot': re.compile('\.'),
     'all_symbols': re.compile('([\]\(【\?】。,！[”，\!\.「<>？"（“…《）}》」;:：\){\)\s])')
 }
@@ -33,10 +33,11 @@ SYMBOLS_EN = {
     'bracket_right': re.compile('([\)\]}」】）>])'),
     'book_left': re.compile('([《])'),
     'book_right': re.compile('([》])'),
-    'comma': re.compile('([,，;])'),
-    'end_symbols': re.compile('([?\!…;？！。])'),
+    'comma': re.compile('([,，])'),
+    'end_symbols': re.compile('([?\!…？！。\.])'),
     'en_dot': re.compile('\.'),
     'dash': re.compile('—'),
     'short_dash': re.compile('-'),
-    'all_symbols': re.compile('([\]\(【\?】。,！[”，\!\.「<>？"（“…《）}》」;:：\'‘’\-\—\){\)\s])')
+    'semicolon': re.compile('([;；])'),
+    'all_symbols': re.compile('([\]\(【\?】。,！[”，\!\.「<>？"（“…《）}》」;；:：\'‘’\-\—\){\)\s])')
 }
