@@ -71,7 +71,6 @@ encl.
 eng.
 esp.
 Esq.
-etc.
 exclam.
 ext.
 f.
@@ -95,7 +94,6 @@ I.
 ib.
 ibid.
 i.e.
-in.
 inc.
 Inc.
 incl.
@@ -113,7 +111,6 @@ Lieut.
 LL.B
 LL.D
 LL.M
-long.
 Lt.
 m.
 M.A.
@@ -226,4 +223,31 @@ H.K.
 N.Y.
 lng.
 D.C.
+O.R.P.
+S. 
+B.
+A.
+C.
+D.
+E.
+F.
+G.
+H.
+I.
+J.
+K.
+L.
+M.
+N.
+O.
+P.
+Q.
+R.
+T.
+U.
+V.
+W.
+X.
+Y.
+Z.
 '''
