@@ -4,16 +4,12 @@
 # LAST MODIFIED ON:
 # AIM:
 import attrdict
-import pathlib
-import os
 
 from .automata import condition, operation
 from .automata import symbols
-from .automata.sequence import EnSequence
+from .automata.white_list import data
 
 SYMBOLS = symbols.SYMBOLS_EN
-FOLDER_PATH = pathlib.Path(__file__).absolute().parents[0]
-WHITE_LIST_PATH = os.path.join(FOLDER_PATH, 'automata/white_list.txt')
 
 
 def init_nodes(**kwargs):
@@ -35,7 +31,7 @@ def init_nodes(**kwargs):
 
         # --- sepcial Condition --- #
         'special_ends': condition.SpecialEnds(),
-        'not_in_white_list': condition.NotInWhitelistDotEn(WHITE_LIST_PATH),
+        'not_in_white_list': condition.NotInWhitelistDotEn(data),
         'is_empty': condition.IsSpace(SYMBOLS),
         'is_left_quota': condition.IsLeftQuotaEn(),
         'is_left_single_quota': condition.IsLeftSingleQuotaEn(),
@@ -47,13 +43,14 @@ def init_nodes(**kwargs):
     nodes = attrdict.AttrDict({
         'do_cut': operation.Normal(SYMBOLS, name='do_cut'),
         'cut_pre_idx': operation.CutPreIdx(SYMBOLS, name='cut_per_idx'),
-        'long_handler': operation.LongHandlerEN(SYMBOLS, white_list_path=WHITE_LIST_PATH, min_sentence_length=min_len,
+        'long_handler': operation.LongHandlerEN(SYMBOLS, white_list=data, min_sentence_length=min_len,
                                                 name='long_handler'),
         'init': operation.Indolent(SYMBOLS),
         'quota_handler': operation.Indolent(SYMBOLS, name='quota_handler'),
         'quota_single_handler': operation.Indolent(SYMBOLS, name='quota_single_handler'),
-        'end': operation.EndState(SYMBOLS)
+        #'end': operation.EndState(SYMBOLS)
     })
+    nodes['end'] = operation.CleanNode(node_list=list(nodes.values()))
     return edges, nodes
 
 
